# {{ cookiecutter.project_name }} roadmap

## Planned features for next release

You will find below the features that will be added in the next release

## Backlog

You will find below some nice to have features that are not planned to be implemented yet.